==> masonite_orm-2.22.1.tar.gz: masonite_orm-2.22.1/tests/mssql/grammar/test_mssql_qmark.py <==
import unittest

from src.masoniteorm.query import QueryBuilder
from src.masoniteorm.query.grammars import MSSQLGrammar


class TestMSSQLQmark(unittest.TestCase):
    def setUp(self):
        self.builder = QueryBuilder(MSSQLGrammar, table="users")

    def test_can_compile_select(self):
        mark = self.builder.select("username").where("name", "Joe")

        sql = "SELECT [users].[username] FROM [users] WHERE [users].[name] = '?'"
        self.assertEqual(mark.to_qmark(), sql)
        self.assertEqual(mark._bindings, ["Joe"])

    def test_can_compile_update(self):
        mark = self.builder.update({"name": "Bob"}, dry=True).where("name", "Joe")

        sql = "UPDATE [users] SET [users].[name] = '?' WHERE [users].[name] = '?'"
        self.assertEqual(mark.to_qmark(), sql)
        self.assertEqual(mark._bindings, ["Bob", "Joe"])

    def test_can_compile_insert(self):
        mark = self.builder.create({"name": "Bob"}, query=True)

        sql = "INSERT INTO [users] ([users].[name]) VALUES ('?')"
        self.assertEqual(mark.to_qmark(), sql)
        self.assertEqual(mark._bindings, ["Bob"])

    def test_can_compile_where_in(self):
        mark = self.builder.where_in("id", [1, 2, 3])

        qmark_sql = "SELECT * FROM [users] WHERE [users].[id] IN ('?', '?', '?')"
        sql = "SELECT * FROM [users] WHERE [users].[id] IN ('1','2','3')"
        self.assertEqual(mark.to_qmark(), qmark_sql)
        self.assertEqual(mark._bindings, [1, 2, 3])
        self.assertEqual(self.builder.where_in("id", [1, 2, 3]).to_sql(), sql)
        self.builder.reset()
        # Assert that when passed string values it generates synonymous sql
        self.assertEqual(self.builder.where_in("id", ["1", "2", "3"]).to_sql(), sql)

==> masonite_orm-3.0.0.tar.gz: masonite_orm-3.0.0/tests/mssql/grammar/test_mssql_qmark.py <==
import unittest

from src.masoniteorm.query import QueryBuilder
from src.masoniteorm.query.grammars import MSSQLGrammar


class TestMSSQLQmark(unittest.TestCase):
    def setUp(self):
        self.builder = QueryBuilder(MSSQLGrammar, table="users")

    def test_can_compile_select(self):
        mark = self.builder.select("username").where("name", "Joe")

        sql = "SELECT [users].[username] FROM [users] WHERE [users].[name] = ?"
        self.assertEqual(mark.to_qmark(), sql)
        self.assertEqual(mark._bindings, ["Joe"])

    def test_can_compile_update(self):
        mark = self.builder.update({"name": "Bob"}, dry=True).where("name", "Joe")

        sql = "UPDATE [users] SET [users].[name] = ? WHERE [users].[name] = ?"
        self.assertEqual(mark.to_qmark(), sql)
        self.assertEqual(mark._bindings, ["Bob", "Joe"])

    def test_can_compile_insert(self):
        mark = self.builder.create({"name": "Bob"}, query=True)

        sql = "INSERT INTO [users] ([users].[name]) VALUES (?)"
        self.assertEqual(mark.to_qmark(), sql)
        self.assertEqual(mark._bindings, ["Bob"])

    def test_can_compile_where_in(self):
        mark = self.builder.where_in("id", [1, 2, 3])

        qmark_sql = "SELECT * FROM [users] WHERE [users].[id] IN (?, ?, ?)"
        sql = "SELECT * FROM [users] WHERE [users].[id] IN ('1','2','3')"
        self.assertEqual(mark.to_qmark(), qmark_sql)
        self.assertEqual(mark._bindings, [1, 2, 3])
        self.assertEqual(self.builder.where_in("id", [1, 2, 3]).to_sql(), sql)
        self.builder.reset()
        # Assert that when passed string values it generates synonymous sql
        self.assertEqual(self.builder.where_in("id", ["1", "2", "3"]).to_sql(), sql)
